@@ -30,9 +30,10 @@ class DataConfig:
     entries_dump = base_data_folder + "/entries_dumped/latest"
     entries_dump_file = base_data_folder + "/entries_dumped/latest/000.parquet"
     cached_configuration = "/tmp/search_and_run_configuration_cached"
-    MLFLOW_MODELS_PATH = f"{os.environ['HOME']}/projects/PySearchEntries/mlflow"
+    MLFLOW_MODELS_PATH = f"/entries/mlflow"
     BASELINE_EXPERIMENT_NAME = f"baseline_rank_v0"
     NEXT_ITEM_EXPERIMENT_NAME = f"next_item_v1"
+    ENTRY_TYPE_CLASSIFIER_EXPERIMENT_NAME = f"entry_type_classifier_v2"
     DATA_WAREHOUSE_FOLDER = base_data_folder + "/data_warehouse"
     CLEAN_EVENTS_FOLDER = DATA_WAREHOUSE_FOLDER + "/clean"
     SEARCH_RUNS_PERFORMED_FOLDER = (
@@ -50,8 +51,8 @@ class KafkaConfig:
 
 
 class RedisConfig:
-    host = "localhost"
-    port = 6379 if is_mac() else 6378
+    host =  "127.0.0.1" if is_mac() else "host.docker.internal"
+    port = 6379
 
 
 class PythonSearchConfiguration(EntriesGroup):
