@@ -3,13 +3,10 @@ from __future__ import annotations
 import datetime
 import time
 
-from grimoire.event_sourcing.message import MessageBroker
-from grimoire.string import emptish
-
 from python_search.apps.clipboard import Clipboard
-from python_search.entry_capture.entry_inserter import EntryInserter
+from python_search.entry_capture.filesystem_entry_inserter import FilesystemEntryInserter
 from python_search.entry_capture.entry_inserter_gui import (EntryCaptureGUI,
-                                                            EntryData)
+                                                            GuiEntryData)
 from python_search.entry_type.entity import infer_default_type
 from python_search.exceptions import RegisterNewException
 from python_search.interpreter.base import BaseInterpreter
@@ -18,40 +15,12 @@ from python_search.interpreter.interpreter_matcher import InterpreterMatcher
 
 class RegisterNew:
     """
-    Responsible for registering new entries in your catalog
+    Entry point for the registering of new entries
     """
 
     def __init__(self, configuration):
         self.configuration = configuration
-        self.message_broker = MessageBroker("search_run_register_new")
-        self.entry_inserter = EntryInserter(configuration)
-
-    def launch_ui(self, default_type=None, default_key=None, default_content=None):
-        """
-        Create a new inferred entry based on the clipboard content
-        """
-
-        if not default_content:
-            default_content = Clipboard().get_content()
-
-        if not default_type:
-            default_type = infer_default_type(default_content)
-
-        entry_data: EntryData = EntryCaptureGUI().launch(
-            "New Entry Details",
-            default_content=default_content,
-            default_key=default_key,
-            default_type=default_type,
-        )
-        interpreter: BaseInterpreter = InterpreterMatcher.build_instance(
-            self.configuration
-        ).get_interpreter_from_type(entry_data.type)
-
-        dict_entry = interpreter(entry_data.value).to_dict()
-        if entry_data.tags:
-            dict_entry["tags"] = entry_data.tags
-
-        self.entry_inserter.insert(entry_data.key, dict_entry)
+        self.entry_inserter = FilesystemEntryInserter(configuration)
 
     def register(self, *, key: str, value: str, tag: str = None):
         """
@@ -65,6 +34,8 @@ class RegisterNew:
 
         """
 
+        key = self._sanitize_key(key)
+
         interpreter: BaseInterpreter = InterpreterMatcher.build_instance(
             self.configuration
         ).get_interpreter(value)
@@ -74,6 +45,39 @@ class RegisterNew:
 
         self.entry_inserter.insert(key, dict_entry)
 
+    def _sanitize_key(self, key):
+        return key.replace("\n", " ").replace(":", " ")
+
+    def launch_ui(self, default_type=None, default_key=None, default_content=None):
+        """
+        Create a new inferred entry based on the clipboard content
+        """
+
+        if not default_content:
+            default_content = Clipboard().get_content()
+
+        # @todo reenable this once in the dockerfile
+        if not default_type:
+            default_type = infer_default_type(default_content)
+
+        entry_data: GuiEntryData = EntryCaptureGUI().launch(
+            "New Entry Details",
+            default_content=default_content,
+            default_key=default_key,
+            default_type=default_type,
+        )
+        key = self._sanitize_key(entry_data.key)
+        interpreter: BaseInterpreter = InterpreterMatcher.build_instance(
+            self.configuration
+        ).get_interpreter_from_type(entry_data.type)
+
+        dict_entry = interpreter(entry_data.value).to_dict()
+        if entry_data.tags:
+            dict_entry["tags"] = entry_data.tags
+
+        self.entry_inserter.insert(key, dict_entry)
+
+
     def anonymous_snippet(self):
         """
         Create an anonymous snippet entry
@@ -106,7 +110,7 @@ class RegisterNew:
 
         meaning = CollectInput().launch(f"Please type the meaning of ({german_term})")
 
-        if emptish(meaning):
+        if not meaning:
             raise RegisterNewException.empty_content()
 
         as_dict = {
